@@ -2,4 +2,4 @@ __author__ = 'Fulfil.IO Inc.'
 __email__ = 'tech-support@fulfil.io'
 __version__ = '0.1.0'
 
-from jet import *
+from .jet import *  # noqa
